@@ -1,6 +1,6 @@
 getFiniteNri <- function(x)
 {
-  if (class(x) != "Nri")
+  if (class(x)[1] != "Nri")
     stop("'x' must be of class Nri")
   
   
@@ -22,4 +22,4 @@ getFiniteNri <- function(x)
                           dim2=as.vector(wl2[result==1 & is.finite(result) & lower.tri(result)]))
   relevant <- data.frame(Band_1=x$wavelength[relevant$dim1], Band_2=x$wavelength[relevant$dim2])
   return(list(Indices=relevant, Models=NULL))
-}
\ No newline at end of file
+}
